@@ -212,6 +212,9 @@ typedef struct {
 #define IPV6CALC_DB_SIZE_ISP_NAME	128+1
 #define IPV6CALC_DB_SIZE_CONN_TYPE	20+1
 #define IPV6CALC_DB_SIZE_ORG_NAME	128+1
+#define IPV6CALC_DB_SIZE_ORG_DOMAIN	128+1
+#define IPV6CALC_DB_SIZE_ORG_USAGE_TYPE	128+1
+#define IPV6CALC_DB_SIZE_ORG_CIDR	128+1
 #define IPV6CALC_DB_SIZE_DOMAIN		20+1
 #define IPV6CALC_DB_SIZE_DMA_CODE	8+1
 #define IPV6CALC_DB_SIZE_IDD_CODE	8+1
@@ -271,6 +274,9 @@ typedef struct
 	char     mobile_country_code[IPV6CALC_DB_SIZE_MOBILECOUNTRYCODE];
 	char     mobile_brand[IPV6CALC_DB_SIZE_MOBILE_BRAND];
 	char     usage_type[IPV6CALC_DB_SIZE_USAGE_TYPE];
+	char     organization_domain[IPV6CALC_DB_SIZE_ORG_DOMAIN];
+	char     organization_usage_type[IPV6CALC_DB_SIZE_ORG_USAGE_TYPE];
+	char     organization_cidr[IPV6CALC_DB_SIZE_ORG_CIDR];
 } libipv6calc_db_wrapper_geolocation_record;
 
 static const s_data_sources geonameid_types[] = {
@@ -399,6 +405,7 @@ extern int  libipv6calc_db_wrapper_init(const char *prefix_string);
 extern int  libipv6calc_db_wrapper_cleanup(void);
 extern void libipv6calc_db_wrapper_info(char *string, const size_t size);
 extern void libipv6calc_db_wrapper_features(char *string, const size_t size);
+extern int libipv6calc_db_wrapper_features_support_by_name(const char* feature_name);
 extern void libipv6calc_db_wrapper_capabilities(char *string, const size_t size);
 extern void libipv6calc_db_wrapper_features_help(void);
 extern void libipv6calc_db_wrapper_print_db_info(const int level_verbose, const char *prefix_string);
