@@ -1,8 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : databases/lib/libipv6calc_db_wrapper_BuiltIn.c
- * Version    : $Id: dfd3157323edf7dd4bdaa165125f6b012f569f9b $
- * Copyright  : 2013-2021 by Peter Bieringer <pb (at) bieringer.de>
+ * Copyright  : 2013-2024 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  ipv6calc BuiltIn database wrapper
@@ -290,16 +289,17 @@ char *libipv6calc_db_wrapper_BuiltIn_wrapper_db_info_used(void) {
 
 			DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_BuiltIn, "type=%d info=%s", type, info);
 
+			STRCLR(tempstring);
 			if (strlen(builtin_db_usage_string) > 0) {
 				if (strstr(builtin_db_usage_string, info) != NULL) {
 					DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_BuiltIn, "type=%d info=%s (skip, already displayed)", type, info);
 					continue;
 				}; // string already included
 
-				snprintf(tempstring, sizeof(tempstring), "%s / %s", builtin_db_usage_string, info);
-			} else {
-				snprintf(tempstring, sizeof(tempstring), "%s", info);
+				STRCAT(tempstring, builtin_db_usage_string);
+				STRCAT(tempstring, " / ");
 			};
+			STRCAT(tempstring, info);
 
 			snprintf(builtin_db_usage_string, sizeof(builtin_db_usage_string), "%s", tempstring);
 			DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "type=%d builtin_db_usage_string=%s", type, builtin_db_usage_string);
@@ -891,6 +891,10 @@ int libipv6calc_db_wrapper_BuiltIn_registry_num_by_ipv6addr(const ipv6calc_ipv6a
 		return(REGISTRY_6BONE);
 	};
 
+	if ((ipv6addrp->typeinfo & IPV6_ADDR_TYPE2_SRV6) != 0) {
+		return(REGISTRY_SRV6);
+	};
+
 	int result = REGISTRY_UNKNOWN;
 
 #ifdef SUPPORT_DB_IPV6_REG
