@@ -1,8 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : databases/lib/libipv6calc_db_wrapper_External.c
- * Version    : $Id: 1d6ec7f1550d6741dd8ff719d24a8ae362230692 $
- * Copyright  : 2013-2022 by Peter Bieringer <pb (at) bieringer.de>
+ * Copyright  : 2013-2024 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  ipv6calc External (superseeding BuiltIn) database wrapper
@@ -140,27 +139,32 @@ int libipv6calc_db_wrapper_External_wrapper_init(void) {
 
 /*
  * wrapper: External_close
+ * in: dbp
+ * out: 0=ok, 1=error
  */
 static int libipv6calc_db_wrapper_External_close(DB *dbp) {
-	int i, j;
+	int entry, subdb;
+	int ret = 0;
 
-	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_External, "Called");
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "Called with dbp=%p", dbp);
 
 	if (dbp != NULL) {
 		/* cleanup cache entry */
-		for (i = 0; i < MAXENTRIES_ARRAY(libipv6calc_db_wrapper_External_db_file_desc); i++) {
-			for (j = 0; j < IPV6CALC_DBD_SUBDB_MAX; j++) {
-				if (db_ptr_cache[i][j] == dbp) {
-					db_ptr_cache[i][j] = NULL;
-					db_recno_max_cache[i][j] = -1;
+		for (entry = 0; entry < MAXENTRIES_ARRAY(libipv6calc_db_wrapper_External_db_file_desc); entry++) {
+			for (subdb = 0; subdb < IPV6CALC_DBD_SUBDB_MAX; subdb++) {
+				if (db_ptr_cache[entry][subdb] == dbp) {
+					DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "Cleanup db_ptr_cache entry=%d subdb=%d dbp=%p", entry, subdb, dbp);
+					db_ptr_cache[entry][subdb] = NULL;
+					db_recno_max_cache[entry][subdb] = -1;
 				};
 			};
 		};
 
-		dbp->close(dbp, 0);
+		/* close database */
+		ret = dbp->close(dbp, DB_NOSYNC); // DB_NOSYNC: databases are only opened in read-only mode
 	};
 
-	return(0);
+	return(ret);
 };
 
 
@@ -171,21 +175,21 @@ static int libipv6calc_db_wrapper_External_close(DB *dbp) {
  * out: 0=ok, 1=error
  */
 int libipv6calc_db_wrapper_External_wrapper_cleanup(void) {
-	int i, j;
+	int entry, subdb;
 	int hit;
 
 	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_External, "Called");
 
-	for (i = 0; i < MAXENTRIES_ARRAY(libipv6calc_db_wrapper_External_db_file_desc); i++) {
+	for (entry = 0; entry < MAXENTRIES_ARRAY(libipv6calc_db_wrapper_External_db_file_desc); entry++) {
 		hit = 0;
-		for (j = 0; j < IPV6CALC_DBD_SUBDB_MAX; j++) {
-			if (db_ptr_cache[i][j] != NULL) {
+		for (subdb = 0; subdb < IPV6CALC_DBD_SUBDB_MAX; subdb++) {
+			if (db_ptr_cache[entry][subdb] != NULL) {
 				if (hit == 0) {
 					// display debug message only once per i (type)
-					DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "Close External: type=%d desc='%s'", libipv6calc_db_wrapper_External_db_file_desc[i].number, libipv6calc_db_wrapper_External_db_file_desc[i].description);
+					DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "Close External: type=%d entry=%d subdb=%d dbp=%p desc='%s'", libipv6calc_db_wrapper_External_db_file_desc[entry].number, entry, subdb, db_ptr_cache[entry][subdb], libipv6calc_db_wrapper_External_db_file_desc[entry].description);
 					hit = 1;
 				};
-				libipv6calc_db_wrapper_External_close(db_ptr_cache[i][j]);
+				libipv6calc_db_wrapper_External_close(db_ptr_cache[entry][subdb]);
 			};
 		};
 	};
@@ -204,7 +208,7 @@ int libipv6calc_db_wrapper_External_wrapper_cleanup(void) {
 void libipv6calc_db_wrapper_External_wrapper_info(char* string, const size_t size) {
 	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_External, "Called");
 
-	snprintf(string, size, "External available databases: Country4=%d Country6=%d IPV4_REG=%d IPV6_REG=%d", \
+	snprintf(string, size, "External(BDB) available databases: Country4=%d Country6=%d IPV4_REG=%d IPV6_REG=%d", \
 		(wrapper_features & IPV6CALC_DB_IPV4_TO_CC) ? 1 : 0, \
 		(wrapper_features & IPV6CALC_DB_IPV6_TO_CC) ? 1 : 0, \
 		(wrapper_features & IPV6CALC_DB_IPV4_TO_REGISTRY) ? 1 : 0, \
@@ -233,24 +237,24 @@ void libipv6calc_db_wrapper_External_wrapper_print_db_info(const int level_verbo
 
 	IPV6CALC_DB_FEATURE_INFO(prefix, IPV6CALC_DB_SOURCE_EXTERNAL)
 
-	fprintf(stderr, "%sExternal: info of available databases in directory: %s\n", prefix, external_db_dir);
+	fprintf(stderr, "%sExternal(BDB): info of available databases in directory: %s\n", prefix, external_db_dir);
 
 	for (i = 0; i < MAXENTRIES_ARRAY(libipv6calc_db_wrapper_External_db_file_desc); i++) {
 		type = libipv6calc_db_wrapper_External_db_file_desc[i].number;
 
 		if (libipv6calc_db_wrapper_External_db_avail(type)) {
-			fprintf(stderr, "%sExternal: %-20s: %-40s (%s)\n", prefix, libipv6calc_db_wrapper_External_db_file_desc[i].description, libipv6calc_db_wrapper_External_db_file_desc[i].filename, libipv6calc_db_wrapper_External_database_info(type));
+			fprintf(stderr, "%sExternal(BDB): %-20s: %-40s (%s)\n", prefix, libipv6calc_db_wrapper_External_db_file_desc[i].description, libipv6calc_db_wrapper_External_db_file_desc[i].filename, libipv6calc_db_wrapper_External_database_info(type));
 			count++;
 		} else {
 			if (level_verbose == LEVEL_VERBOSE2) {
-				fprintf(stderr, "%sExternal: %-20s: %-40s (%s)\n", prefix, libipv6calc_db_wrapper_External_db_file_desc[i].description, libipv6calc_db_wrapper_External_dbfilename(type), strerror(errno));
+				fprintf(stderr, "%sExternal(BDB): %-20s: %-40s (%s)\n", prefix, libipv6calc_db_wrapper_External_db_file_desc[i].description, libipv6calc_db_wrapper_External_dbfilename(type), strerror(errno));
 			};
 			continue;
 		};
 	};
 
 	if (count == 0) {
-		fprintf(stderr, "%sExternal: NO available databases found in directory: %s\n", prefix, external_db_dir);
+		fprintf(stderr, "%sExternal(BDB): NO available databases found in directory: %s\n", prefix, external_db_dir);
 	};
 
 	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_External, "Finished");
@@ -284,16 +288,17 @@ char *libipv6calc_db_wrapper_External_wrapper_db_info_used(void) {
 
 			DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "type=%d info=%s", type, info);
 
+			STRCLR(tempstring);
 			if (strlen(external_db_usage_string) > 0) {
 				if (strstr(external_db_usage_string, info) != NULL) {
 					DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "type=%d info=%s (skip, already displayed)", type, info);
 					continue;
 				}; // string already included
 
-				snprintf(tempstring, sizeof(tempstring), "%s / %s", external_db_usage_string, info);
-			} else {
-				snprintf(tempstring, sizeof(tempstring), "%s", info);
+				STRCAT(tempstring, external_db_usage_string);
+				STRCAT(tempstring, " / ");
 			};
+			STRCAT(tempstring, info);
 
 			snprintf(external_db_usage_string, sizeof(external_db_usage_string), "%s", tempstring);
 			DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "type=%d external_db_usage_string=%s", type, external_db_usage_string);
@@ -328,7 +333,10 @@ static char *libipv6calc_db_wrapper_External_dbfilename(unsigned int type) {
 		return(NULL);
 	};
 
-	snprintf(tempstring, sizeof(tempstring), "%s/%s", external_db_dir, libipv6calc_db_wrapper_External_db_file_desc[i].filename);
+	STRCLR(tempstring);
+	STRCAT(tempstring, external_db_dir);
+	STRCAT(tempstring, "/");
+	STRCAT(tempstring, libipv6calc_db_wrapper_External_db_file_desc[i].filename);
 
 	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "Finished: %s type=%d has filename=%s", wrapper_external_info, type, tempstring);
 
@@ -450,7 +458,7 @@ DB *libipv6calc_db_wrapper_External_open_type(const unsigned int type_flag, long
 			*db_recno_max_ptr = db_recno_max_cache[entry][subdb];
 		};
 
-		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "Database already opened (cached) dbp=%p type=%d subdb=%d recno_max: %u", dbp, type, subdb, db_recno_max_cache[entry][subdb]);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "Database already opened (cached) dbp=%p type=%d entry=%d subdb=%d recno_max: %u", dbp, type, entry, subdb, db_recno_max_cache[entry][subdb]);
 
 		goto END_libipv6calc_db_wrapper;
 	};
@@ -545,7 +553,6 @@ END_libipv6calc_db_wrapper:
 char *libipv6calc_db_wrapper_External_database_info(const unsigned int type) {
 	static char resultstring[IPV6CALC_STRING_MAX] = ""; // has to be static because pointer is returned
 	char datastring[IPV6CALC_STRING_MAX];
-	char tempstring[IPV6CALC_STRING_MAX];
 	int ret, i, entry = -1;
 	DB *dbp;
 
@@ -591,7 +598,8 @@ char *libipv6calc_db_wrapper_External_database_info(const unsigned int type) {
 		goto END_libipv6calc_db_wrapper_close;
 	};
 
-	snprintf(resultstring, sizeof(resultstring), "EXTDB-%d/%s", type, datastring);
+	snprintf(resultstring, sizeof(resultstring), "EXTDB-%d/", type);
+	STRCAT(resultstring, datastring);
 
 	// get dbcreated_unixtime
 	ret = libipv6calc_db_wrapper_bdb_get_data_by_key(dbp, "dbcreated_unixtime", datastring, sizeof(datastring));
@@ -610,8 +618,8 @@ char *libipv6calc_db_wrapper_External_database_info(const unsigned int type) {
 	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_External, "wrapper_db_unixtime_External=%ld", (long int) wrapper_db_unixtime_External[entry]);
 
 	strftime(datastring, sizeof(datastring), "%Y%m%d-%H%M%S UTC", gmtime(&wrapper_db_unixtime_External[entry]));
-	snprintf(tempstring, sizeof(tempstring), "%s, created: %s", resultstring, datastring);
-	snprintf(resultstring, sizeof(resultstring), "%s", tempstring);
+	STRCAT(resultstring, ", created: ");
+	STRCAT(resultstring, datastring);
 
 END_libipv6calc_db_wrapper_close:
 	libipv6calc_db_wrapper_External_close(dbp);
@@ -842,7 +850,7 @@ END_libipv6calc_db_wrapper:
 int libipv6calc_db_wrapper_External_country_code_by_addr(const ipv6calc_ipaddr *ipaddrp, char *country, const size_t country_len) {
 	DB *dbp;
 	long int recno_max;
-	static char resultstring[IPV6CALC_STRING_MAX];
+	char resultstring[IPV6CALC_STRING_MAX];
 	int result;
 	int retval = -1;
 
@@ -1263,16 +1271,16 @@ int libipv6calc_db_wrapper_External_dump(const int selector, const s_ipv6calc_fi
 	if (filter_db_cc->cc_must_have_max > 0) {
 		for (i = 0; i < filter_db_cc->cc_must_have_max; i++) {
 			libipv6calc_db_wrapper_country_code_by_cc_index(cc2, sizeof(cc2), filter_db_cc->cc_must_have[i]);
-			snprintf(tempstring, sizeof(tempstring), "%s %s", filterstring, cc2); 
-			snprintf(filterstring, sizeof(filterstring), "%s", tempstring);
+			STRCAT(filterstring, " ");
+			STRCAT(filterstring, cc2);
 		};
 	};
 
 	if (filter_db_cc->cc_may_not_have_max > 0) {
 		for (i = 0; i < filter_db_cc->cc_may_not_have_max; i++) {
 			libipv6calc_db_wrapper_country_code_by_cc_index(cc2, sizeof(cc2), filter_db_cc->cc_may_not_have[i]);
-			snprintf(tempstring, sizeof(tempstring), "%s ^%s", filterstring, cc2); 
-			snprintf(filterstring, sizeof(filterstring), "%s", tempstring);
+			STRCAT(filterstring, " ");
+			STRCAT(filterstring, cc2);
 		};
 	};
 
