@@ -1,11 +1,10 @@
 /*
  * Project    : ipv6calc
  * File       : databases/lib/libipv6calc_db_wrapper_GeoIP2.c
- * Version    : $Id: cf6ecb9284d4a82fc1056f206c90dd1f330f22dc $
- * Copyright  : 2019-2021 by Peter Bieringer <pb (at) bieringer.de>
+ * Copyright  : 2019-2025 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
- *  ipv6calc DB-IP.com database wrapper for MaxMindDB databases
+ *  ipv6calc GeoIP2 database wrapper for MaxMindDB databases
  */
 
 #include <stdio.h>
@@ -39,25 +38,25 @@ static const db_file_desc2 libipv6calc_db_wrapper_GeoIP2_db_file_desc[] = {
 	// country (lite)
 	{ GeoIP2_DB_COUNTRY_LITE
 		, "GeoLite2-Country.mmdb"
-		, "IPv4/v6 CountryCode (FREE)"
+		, "IPv4/v6 CountryCode (LITE)"
 		, IPV6CALC_DB_IP_TO_CC | IPV6CALC_DB_IP_TO_GEONAMEID | IPV6CALC_DB_IP_TO_COUNTRY | IPV6CALC_DB_GEOIP
-		, IPV6CALC_DB_GEOIP2_INTERNAL_FREE
+		, IPV6CALC_DB_GEOIP2_INTERNAL_LITE
 	},
 
 	// city (lite)
 	{ GeoIP2_DB_CITY_LITE
 		, "GeoLite2-City.mmdb"
-		, "IPv4/v6 City (FREE)"
+		, "IPv4/v6 City (LITE)"
 		, IPV6CALC_DB_IP_TO_CITY | IPV6CALC_DB_IP_TO_REGION | IPV6CALC_DB_IP_TO_CC | IPV6CALC_DB_GEOIP | IPV6CALC_DB_IP_TO_GEONAMEID
-		, IPV6CALC_DB_GEOIP2_INTERNAL_FREE
+		, IPV6CALC_DB_GEOIP2_INTERNAL_LITE
 	},
 
 	// ASN (lite)
 	{ GeoIP2_DB_ASN
 		, "GeoLite2-ASN.mmdb"
-		, "IPv4/v6 ASN (FREE)"
+		, "IPv4/v6 ASN (LITE)"
 		, IPV6CALC_DB_IP_TO_AS | IPV6CALC_DB_GEOIP
-		, IPV6CALC_DB_GEOIP2_INTERNAL_FREE
+		, IPV6CALC_DB_GEOIP2_INTERNAL_LITE
 	},
 
 	// country
@@ -93,39 +92,33 @@ static int geoip2_db_region_city_v4 = 0;
 static int geoip2_db_region_city_v6 = 0;
 static int geoip2_db_asn_v4 = 0;
 static int geoip2_db_asn_v6 = 0;
+static int geoip2_db_geonameid_v4 = 0;
+static int geoip2_db_geonameid_v6 = 0;
 
-typedef struct {
-	unsigned int num;
-	int dbtype;
-	int dbym;
-} s_ipv6calc_geoip2_db;
-
-#define GeoIP2_FREE	0
+#define GeoIP2_LITE	0
 #define GeoIP2_COMM	1
 #define	GeoIP2_MAX	2
 
-static s_ipv6calc_geoip2_db geoip2_db_country_v4_best[GeoIP2_MAX];
-static s_ipv6calc_geoip2_db geoip2_db_country_v6_best[GeoIP2_MAX];
-static s_ipv6calc_geoip2_db geoip2_db_region_city_v4_best[GeoIP2_MAX];
-static s_ipv6calc_geoip2_db geoip2_db_region_city_v6_best[GeoIP2_MAX];
-static s_ipv6calc_geoip2_db geoip2_db_asn_v4_best[GeoIP2_MAX];
-static s_ipv6calc_geoip2_db geoip2_db_asn_v6_best[GeoIP2_MAX];
+static s_libipv6calc_db_wrapper_db_info geoip2_db_country_v4_best[GeoIP2_MAX];
+static s_libipv6calc_db_wrapper_db_info geoip2_db_country_v6_best[GeoIP2_MAX];
+static s_libipv6calc_db_wrapper_db_info geoip2_db_region_city_v4_best[GeoIP2_MAX];
+static s_libipv6calc_db_wrapper_db_info geoip2_db_region_city_v6_best[GeoIP2_MAX];
+static s_libipv6calc_db_wrapper_db_info geoip2_db_asn_v4_best[GeoIP2_MAX];
+static s_libipv6calc_db_wrapper_db_info geoip2_db_asn_v6_best[GeoIP2_MAX];
+static s_libipv6calc_db_wrapper_db_info geoip2_db_geonameid_v4_best[GeoIP2_MAX];
+static s_libipv6calc_db_wrapper_db_info geoip2_db_geonameid_v6_best[GeoIP2_MAX];
 
 static int type2index[GeoIP2_DB_MAX+1];
 
-// select FREE database if COMM is older than given months
+// select LITE database if COMM is older than given months
 int geoip2_db_comm_to_free_switch_min_delta_months = 12;
 
-// select better database of same product (COMM/FREE) only if not older than given months
+// select better database of same product (COMM/LITE) only if not older than given months
 int geoip2_db_better_max_delta_months = 1;
 
 // select only a specific GeoIP2 db type
 int geoip2_db_only_type = 0;
 
-
-#define GeoIP2_UNPACK_YM(dbym) ((dbym > 0) ? ((dbym % 12) + ((dbym / 12)) * 100) : 0)
-
-
 /* database usage map */
 #define GeoIP2_DB_MAX_BLOCKS_32	2	// 0-63
 static uint32_t geoip2_db_usage_map[GeoIP2_DB_MAX_BLOCKS_32];
@@ -197,8 +190,8 @@ int libipv6calc_db_wrapper_GeoIP2_wrapper_init(void) {
 			continue;
 		};
 
-		if ((libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].internal & IPV6CALC_DB_GEOIP2_INTERNAL_FREE) != 0) {
-			product = GeoIP2_FREE;
+		if ((libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].internal & IPV6CALC_DB_GEOIP2_INTERNAL_LITE) != 0) {
+			product = GeoIP2_LITE;
 		} else {
 			product = GeoIP2_COMM;
 		};
@@ -206,8 +199,8 @@ int libipv6calc_db_wrapper_GeoIP2_wrapper_init(void) {
 		time_t db_time = mmdb_cache[dbtype].metadata.build_epoch;
 		struct tm *db_gmtime = gmtime(&db_time);
 
-		dbym = (db_gmtime->tm_year + 1900) * 12 + (db_gmtime->tm_mon + 1);
-		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP2, "GEOIP2 type=%d dbym=%d Year/Month=%d unixtime=%llu", dbtype, dbym, GeoIP2_UNPACK_YM(dbym), (long long unsigned int) mmdb_cache[dbtype].metadata.build_epoch);
+		dbym = (db_gmtime->tm_year + 1900) * 12 + db_gmtime->tm_mon;
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP2, "GeoIP2 type=%d dbym=%d Year/Month=%d unixtime=%llu", dbtype, dbym, UNPACK_YM(dbym), (long long unsigned int) mmdb_cache[dbtype].metadata.build_epoch);
 
 #define GeoIP2_DB_SELECT_BETTER(best) \
 			if ( \
@@ -248,24 +241,34 @@ int libipv6calc_db_wrapper_GeoIP2_wrapper_init(void) {
 			GeoIP2_DB_SELECT_BETTER(geoip2_db_asn_v6_best[product])
 		};
 
+		if ((libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].features & IPV6CALC_DB_IPV4_TO_GEONAMEID) != 0) {
+			GeoIP2_DB_SELECT_BETTER(geoip2_db_geonameid_v4_best[product])
+		};
+
+		if ((libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].features & IPV6CALC_DB_IPV6_TO_GEONAMEID) != 0) {
+			GeoIP2_DB_SELECT_BETTER(geoip2_db_geonameid_v6_best[product])
+		};
+
 		wrapper_features_by_source[IPV6CALC_DB_SOURCE_GEOIP2] |= libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].features;
 	};
 
 	// select free instead of comm, if comm is outdated and free available
 	if (geoip2_db_comm_to_free_switch_min_delta_months > 0) {
 		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP2, "GeoIP2 database priority check (comm->free) after months: %d", geoip2_db_comm_to_free_switch_min_delta_months);
-#define SELECT_FREE_INSTEAD_OF_COMM(free, comm, final) \
+#define SELECT_LITE_INSTEAD_OF_COMM(free, comm, final) \
 	if ((free.num > 0) && (comm.num > 0)) { \
 		if (free.dbym - comm.dbym > geoip2_db_comm_to_free_switch_min_delta_months) { \
 			final = free.num; \
 		}; \
 	};
-		SELECT_FREE_INSTEAD_OF_COMM(geoip2_db_country_v4_best[GeoIP2_FREE], geoip2_db_country_v4_best[GeoIP2_COMM], geoip2_db_country_v4)
-		SELECT_FREE_INSTEAD_OF_COMM(geoip2_db_country_v6_best[GeoIP2_FREE], geoip2_db_country_v6_best[GeoIP2_COMM], geoip2_db_country_v6)
-		SELECT_FREE_INSTEAD_OF_COMM(geoip2_db_region_city_v4_best[GeoIP2_FREE], geoip2_db_region_city_v4_best[GeoIP2_COMM], geoip2_db_region_city_v4)
-		SELECT_FREE_INSTEAD_OF_COMM(geoip2_db_region_city_v6_best[GeoIP2_FREE], geoip2_db_region_city_v6_best[GeoIP2_COMM], geoip2_db_region_city_v6)
-		SELECT_FREE_INSTEAD_OF_COMM(geoip2_db_asn_v4_best[GeoIP2_FREE], geoip2_db_asn_v4_best[GeoIP2_COMM], geoip2_db_asn_v4)
-		SELECT_FREE_INSTEAD_OF_COMM(geoip2_db_asn_v6_best[GeoIP2_FREE], geoip2_db_asn_v6_best[GeoIP2_COMM], geoip2_db_asn_v6)
+		SELECT_LITE_INSTEAD_OF_COMM(geoip2_db_country_v4_best[GeoIP2_LITE], geoip2_db_country_v4_best[GeoIP2_COMM], geoip2_db_country_v4)
+		SELECT_LITE_INSTEAD_OF_COMM(geoip2_db_country_v6_best[GeoIP2_LITE], geoip2_db_country_v6_best[GeoIP2_COMM], geoip2_db_country_v6)
+		SELECT_LITE_INSTEAD_OF_COMM(geoip2_db_region_city_v4_best[GeoIP2_LITE], geoip2_db_region_city_v4_best[GeoIP2_COMM], geoip2_db_region_city_v4)
+		SELECT_LITE_INSTEAD_OF_COMM(geoip2_db_region_city_v6_best[GeoIP2_LITE], geoip2_db_region_city_v6_best[GeoIP2_COMM], geoip2_db_region_city_v6)
+		SELECT_LITE_INSTEAD_OF_COMM(geoip2_db_asn_v4_best[GeoIP2_LITE], geoip2_db_asn_v4_best[GeoIP2_COMM], geoip2_db_asn_v4)
+		SELECT_LITE_INSTEAD_OF_COMM(geoip2_db_asn_v6_best[GeoIP2_LITE], geoip2_db_asn_v6_best[GeoIP2_COMM], geoip2_db_asn_v6)
+		SELECT_LITE_INSTEAD_OF_COMM(geoip2_db_geonameid_v4_best[GeoIP2_LITE], geoip2_db_geonameid_v4_best[GeoIP2_COMM], geoip2_db_geonameid_v4)
+		SELECT_LITE_INSTEAD_OF_COMM(geoip2_db_geonameid_v6_best[GeoIP2_LITE], geoip2_db_geonameid_v6_best[GeoIP2_COMM], geoip2_db_geonameid_v6)
 	};
 
 #define FILL_EMPTY(product, final) \
@@ -280,23 +283,39 @@ int libipv6calc_db_wrapper_GeoIP2_wrapper_init(void) {
 	FILL_EMPTY(geoip2_db_region_city_v6_best[GeoIP2_COMM], geoip2_db_region_city_v6)
 	FILL_EMPTY(geoip2_db_asn_v4_best[GeoIP2_COMM], geoip2_db_asn_v4)
 	FILL_EMPTY(geoip2_db_asn_v6_best[GeoIP2_COMM], geoip2_db_asn_v6)
+	FILL_EMPTY(geoip2_db_geonameid_v4_best[GeoIP2_COMM], geoip2_db_geonameid_v4)
+	FILL_EMPTY(geoip2_db_geonameid_v6_best[GeoIP2_COMM], geoip2_db_geonameid_v6)
 
 	// fill empty ones with free
-	FILL_EMPTY(geoip2_db_country_v4_best[GeoIP2_FREE], geoip2_db_country_v4)
-	FILL_EMPTY(geoip2_db_country_v6_best[GeoIP2_FREE], geoip2_db_country_v6)
-	FILL_EMPTY(geoip2_db_region_city_v4_best[GeoIP2_FREE], geoip2_db_region_city_v4)
-	FILL_EMPTY(geoip2_db_region_city_v6_best[GeoIP2_FREE], geoip2_db_region_city_v6)
-	FILL_EMPTY(geoip2_db_asn_v4_best[GeoIP2_FREE], geoip2_db_asn_v4)
-	FILL_EMPTY(geoip2_db_asn_v6_best[GeoIP2_FREE], geoip2_db_asn_v6)
+	FILL_EMPTY(geoip2_db_country_v4_best[GeoIP2_LITE], geoip2_db_country_v4)
+	FILL_EMPTY(geoip2_db_country_v6_best[GeoIP2_LITE], geoip2_db_country_v6)
+	FILL_EMPTY(geoip2_db_region_city_v4_best[GeoIP2_LITE], geoip2_db_region_city_v4)
+	FILL_EMPTY(geoip2_db_region_city_v6_best[GeoIP2_LITE], geoip2_db_region_city_v6)
+	FILL_EMPTY(geoip2_db_asn_v4_best[GeoIP2_LITE], geoip2_db_asn_v4)
+	FILL_EMPTY(geoip2_db_asn_v6_best[GeoIP2_LITE], geoip2_db_asn_v6)
+	FILL_EMPTY(geoip2_db_geonameid_v4_best[GeoIP2_LITE], geoip2_db_geonameid_v4)
+	FILL_EMPTY(geoip2_db_geonameid_v6_best[GeoIP2_LITE], geoip2_db_geonameid_v6)
 
 	/* close handles which are not necessary further on */
 	for (i = 0; i < MAXENTRIES_ARRAY(libipv6calc_db_wrapper_GeoIP2_db_file_desc); i++) {
 		if (mmdb_cache[libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].number].file_size > 0) {
 			if (
-				(libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].number == geoip2_db_country_v4_best[GeoIP2_FREE].num)
+				(libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].number == geoip2_db_country_v4_best[GeoIP2_LITE].num)
 			    ||	(libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].number == geoip2_db_country_v4_best[GeoIP2_COMM].num)
-			    ||	(libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].number == geoip2_db_country_v6_best[GeoIP2_FREE].num)
+			    ||	(libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].number == geoip2_db_country_v6_best[GeoIP2_LITE].num)
 			    ||	(libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].number == geoip2_db_country_v6_best[GeoIP2_COMM].num)
+			    || 	(libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].number == geoip2_db_region_city_v4_best[GeoIP2_LITE].num)
+			    ||	(libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].number == geoip2_db_region_city_v4_best[GeoIP2_COMM].num)
+			    ||	(libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].number == geoip2_db_region_city_v6_best[GeoIP2_LITE].num)
+			    ||	(libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].number == geoip2_db_region_city_v6_best[GeoIP2_COMM].num)
+			    || 	(libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].number == geoip2_db_asn_v4_best[GeoIP2_LITE].num)
+			    ||	(libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].number == geoip2_db_asn_v4_best[GeoIP2_COMM].num)
+			    ||	(libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].number == geoip2_db_asn_v6_best[GeoIP2_LITE].num)
+			    ||	(libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].number == geoip2_db_asn_v6_best[GeoIP2_COMM].num)
+			    || 	(libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].number == geoip2_db_geonameid_v4_best[GeoIP2_LITE].num)
+			    ||	(libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].number == geoip2_db_geonameid_v4_best[GeoIP2_COMM].num)
+			    ||	(libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].number == geoip2_db_geonameid_v6_best[GeoIP2_LITE].num)
+			    ||	(libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].number == geoip2_db_geonameid_v6_best[GeoIP2_COMM].num)
 			) {
 				// database is in use
 				continue;
@@ -359,13 +378,15 @@ int libipv6calc_db_wrapper_GeoIP2_wrapper_cleanup(void) {
 void libipv6calc_db_wrapper_GeoIP2_wrapper_info(char* string, const size_t size) {
 	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP2, "Called");
 
-	snprintf(string, size, "GeoIP2 database support: Country4=%d Country6=%d ASN4=%d ASN6=%d City4=%d City6=%d", \
-		(wrapper_features & IPV6CALC_DB_IPV4_TO_CC) ? 1 : 0, \
-		(wrapper_features & IPV6CALC_DB_IPV6_TO_CC) ? 1 : 0, \
-		(wrapper_features & IPV6CALC_DB_IPV4_TO_AS) ? 1 : 0, \
-		(wrapper_features & IPV6CALC_DB_IPV6_TO_AS) ? 1 : 0, \
-		(wrapper_features & IPV6CALC_DB_IPV4_TO_CITY) ? 1 : 0, \
-		(wrapper_features & IPV6CALC_DB_IPV6_TO_CITY) ? 1 : 0 \
+	snprintf(string, size, "GeoIP(MMDB) database support: Country4=%d Country6=%d City4=%d City6=%d ASN4=%d ASN6=%d GeonameID4=%d GeonameID6=%d"
+		, (wrapper_features_by_source[IPV6CALC_DB_SOURCE_GEOIP2] & IPV6CALC_DB_IPV4_TO_CC) ? 1 : 0
+		, (wrapper_features_by_source[IPV6CALC_DB_SOURCE_GEOIP2] & IPV6CALC_DB_IPV6_TO_CC) ? 1 : 0
+		, (wrapper_features_by_source[IPV6CALC_DB_SOURCE_GEOIP2] & IPV6CALC_DB_IPV4_TO_CITY) ? 1 : 0
+		, (wrapper_features_by_source[IPV6CALC_DB_SOURCE_GEOIP2] & IPV6CALC_DB_IPV6_TO_CITY) ? 1 : 0
+		, (wrapper_features_by_source[IPV6CALC_DB_SOURCE_GEOIP2] & IPV6CALC_DB_IPV4_TO_AS) ? 1 : 0
+		, (wrapper_features_by_source[IPV6CALC_DB_SOURCE_GEOIP2] & IPV6CALC_DB_IPV6_TO_AS) ? 1 : 0
+		, (wrapper_features_by_source[IPV6CALC_DB_SOURCE_GEOIP2] & IPV6CALC_DB_IPV4_TO_GEONAMEID) ? 1 : 0
+		, (wrapper_features_by_source[IPV6CALC_DB_SOURCE_GEOIP2] & IPV6CALC_DB_IPV6_TO_GEONAMEID) ? 1 : 0
 	);
 
 	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP2, "Finished");
@@ -380,6 +401,7 @@ void libipv6calc_db_wrapper_GeoIP2_wrapper_info(char* string, const size_t size)
  */
 void libipv6calc_db_wrapper_GeoIP2_wrapper_print_db_info(const int level_verbose, const char *prefix_string) {
 	int ret, i, type, count = 0;
+	s_libipv6calc_db_wrapper_db_info_all db_info_all;
 
 	const char *prefix = "\0";
 	if (prefix_string != NULL) {
@@ -390,7 +412,7 @@ void libipv6calc_db_wrapper_GeoIP2_wrapper_print_db_info(const int level_verbose
 
 	IPV6CALC_DB_FEATURE_INFO(prefix, IPV6CALC_DB_SOURCE_GEOIP2)
 
-	fprintf(stderr, "%sGeoIP2: info of available databases in directory: %s\n", prefix, geoip2_db_dir);
+	fprintf(stderr, "%sGeoIP(MMDB): info of available databases in directory: %s\n", prefix, geoip2_db_dir);
 
 	for (i = 0; i < MAXENTRIES_ARRAY(libipv6calc_db_wrapper_GeoIP2_db_file_desc); i++) {
 		type = libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].number;
@@ -399,102 +421,102 @@ void libipv6calc_db_wrapper_GeoIP2_wrapper_print_db_info(const int level_verbose
 			// GeoIP2 returned that database is available
 			ret = libipv6calc_db_wrapper_GeoIP2_open_type(type);
 			if (ret != MMDB_SUCCESS) {
-				fprintf(stderr, "%sGeoIP2: %-30s: [%1d] %-30s (CAN'T OPEN database information)\n", prefix, libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].description, type, libipv6calc_db_wrapper_GeoIP2_dbfilename(type));
+				fprintf(stderr, "%sGeoIP(MMDB): %-30s: [%1d] %-30s (CAN'T OPEN database information)\n", prefix, libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].description, type, libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].filename);
 			} else {
-				fprintf(stderr, "%sGeoIP2: %-30s: [%1d] %-30s (%s)\n", prefix, libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].description, type, libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].filename, libipv6calc_db_wrapper_GeoIP2_database_info(type));
+				fprintf(stderr, "%sGeoIP(MMDB): %-30s: [%1d] %-30s (%s)\n", prefix, libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].description, type, libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].filename, libipv6calc_db_wrapper_GeoIP2_database_info(type));
 				libipv6calc_db_wrapper_GeoIP2_close(type);
 				count++;
 			};
 		} else {
 			if (level_verbose == LEVEL_VERBOSE2) {
-				fprintf(stderr, "%sGeoIP2: %-30s: [%1d] %-30s (%s)\n", prefix, libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].description, type, libipv6calc_db_wrapper_GeoIP2_dbfilename(type), strerror(errno));
+				fprintf(stderr, "%sGeoIP(MMDB): %-30s: [%1d] %-30s (%s)\n", prefix, libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].description, type, libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].filename, strerror(errno));
 			};
 			continue;
 		};
 	};
 
 	if (count == 0) {
-		fprintf(stderr, "%sGeoIP2: NO available databases found in directory: %s\n", prefix, geoip2_db_dir);
+		fprintf(stderr, "%sGeoIP(MMDB): NO available databases found in directory: %s\n", prefix, geoip2_db_dir);
 	} else {
-		if (level_verbose >= LEVEL_VERBOSE2) {
-			fprintf(stderr, "%sGeoIP2: detected best databases FREE    Country4=%-3d DB%-2d %6d  Country6=%-3d DB%-2d %6d  City4=%-3d DB%-2d %6d  City6=%-3d DB%-2d %6d\n"
-				, prefix
-				, geoip2_db_country_v4_best[GeoIP2_FREE].num
-				, geoip2_db_country_v4_best[GeoIP2_FREE].dbtype
-				, GeoIP2_UNPACK_YM(geoip2_db_country_v4_best[GeoIP2_FREE].dbym)
-				, geoip2_db_country_v6_best[GeoIP2_FREE].num
-				, geoip2_db_country_v6_best[GeoIP2_FREE].dbtype
-				, GeoIP2_UNPACK_YM(geoip2_db_country_v6_best[GeoIP2_FREE].dbym)
-				, geoip2_db_region_city_v4_best[GeoIP2_FREE].num
-				, geoip2_db_region_city_v4_best[GeoIP2_FREE].dbtype
-				, GeoIP2_UNPACK_YM(geoip2_db_region_city_v4_best[GeoIP2_FREE].dbym)
-				, geoip2_db_region_city_v6_best[GeoIP2_FREE].num
-				, geoip2_db_region_city_v6_best[GeoIP2_FREE].dbtype
-				, GeoIP2_UNPACK_YM(geoip2_db_region_city_v6_best[GeoIP2_FREE].dbym)
-			);
-
-			fprintf(stderr, "%sGeoIP2: detected best databases COMM    Country4=%-3d DB%-2d %6d  Country6=%-3d DB%-2d %6d  City4=%-3d DB%-2d %6d  City6=%-3d DB%-2d %6d\n"
-				, prefix
-				, geoip2_db_country_v4_best[GeoIP2_COMM].num
-				, geoip2_db_country_v4_best[GeoIP2_COMM].dbtype
-				, GeoIP2_UNPACK_YM(geoip2_db_country_v4_best[GeoIP2_COMM].dbym)
-				, geoip2_db_country_v6_best[GeoIP2_COMM].num
-				, geoip2_db_country_v6_best[GeoIP2_COMM].dbtype
-				, GeoIP2_UNPACK_YM(geoip2_db_country_v6_best[GeoIP2_COMM].dbym)
-				, geoip2_db_region_city_v4_best[GeoIP2_COMM].num
-				, geoip2_db_region_city_v4_best[GeoIP2_COMM].dbtype
-				, GeoIP2_UNPACK_YM(geoip2_db_region_city_v4_best[GeoIP2_COMM].dbym)
-				, geoip2_db_region_city_v6_best[GeoIP2_COMM].num
-				, geoip2_db_region_city_v6_best[GeoIP2_COMM].dbtype
-				, GeoIP2_UNPACK_YM(geoip2_db_region_city_v6_best[GeoIP2_COMM].dbym)
-			);
-		} else if (level_verbose >= LEVEL_VERBOSE) {
-			fprintf(stderr, "%sGeoIP2: detected best databases FREE    Country4=%-3d  Country6=%-3d  City4=%-3d  City6=%-3d\n"
-				, prefix
-				, geoip2_db_country_v4_best[GeoIP2_FREE].num
-				, geoip2_db_country_v6_best[GeoIP2_FREE].num
-				, geoip2_db_region_city_v4_best[GeoIP2_FREE].num
-				, geoip2_db_region_city_v6_best[GeoIP2_FREE].num
-			);
-
-			fprintf(stderr, "%sGeoIP2: detected best databases COMM    Country4=%-3d  Country6=%-3d  City4=%-3d  City6=%-3d\n"
-				, prefix
-				, geoip2_db_country_v4_best[GeoIP2_COMM].num
-				, geoip2_db_country_v6_best[GeoIP2_COMM].num
-				, geoip2_db_region_city_v4_best[GeoIP2_COMM].num
-				, geoip2_db_region_city_v6_best[GeoIP2_COMM].num
-			);
-
-		};
-
 		if (level_verbose >= LEVEL_VERBOSE) {
-			fprintf(stderr, "%sGeoIP2: selected best databases normal  Country4=%-3d%s  Country6=%-3d%s  City4=%-3d%s  City6=%-3d\n"
-				, prefix
-				, geoip2_db_country_v4
-				, (level_verbose >= LEVEL_VERBOSE2) ? "            " : ""
-				, geoip2_db_country_v6
-				, (level_verbose >= LEVEL_VERBOSE2) ? "            " : ""
-				, geoip2_db_region_city_v4
-				, (level_verbose >= LEVEL_VERBOSE2) ? "            " : ""
-				, geoip2_db_region_city_v6
-			);
+			db_info_all.country4.num    = geoip2_db_country_v4_best[GeoIP2_LITE].num;
+			db_info_all.country4.dbtype = geoip2_db_country_v4_best[GeoIP2_LITE].dbtype;
+			db_info_all.country4.dbym   = geoip2_db_country_v4_best[GeoIP2_LITE].dbym;
+			db_info_all.country6.num    = geoip2_db_country_v6_best[GeoIP2_LITE].num;
+			db_info_all.country6.dbtype = geoip2_db_country_v6_best[GeoIP2_LITE].dbtype;
+			db_info_all.country6.dbym   = geoip2_db_country_v6_best[GeoIP2_LITE].dbym;
+			db_info_all.city4.num    = geoip2_db_region_city_v4_best[GeoIP2_LITE].num;
+			db_info_all.city4.dbtype = geoip2_db_region_city_v4_best[GeoIP2_LITE].dbtype;
+			db_info_all.city4.dbym   = geoip2_db_region_city_v4_best[GeoIP2_LITE].dbym;
+			db_info_all.city6.num    = geoip2_db_region_city_v6_best[GeoIP2_LITE].num;
+			db_info_all.city6.dbtype = geoip2_db_region_city_v6_best[GeoIP2_LITE].dbtype;
+			db_info_all.city6.dbym   = geoip2_db_region_city_v6_best[GeoIP2_LITE].dbym;
+			db_info_all.asn4.num    = geoip2_db_asn_v4_best[GeoIP2_LITE].num;
+			db_info_all.asn4.dbtype = geoip2_db_asn_v4_best[GeoIP2_LITE].dbtype;
+			db_info_all.asn4.dbym   = geoip2_db_asn_v4_best[GeoIP2_LITE].dbym;
+			db_info_all.asn6.num    = geoip2_db_asn_v6_best[GeoIP2_LITE].num;
+			db_info_all.asn6.dbtype = geoip2_db_asn_v6_best[GeoIP2_LITE].dbtype;
+			db_info_all.asn6.dbym   = geoip2_db_asn_v6_best[GeoIP2_LITE].dbym;
+			db_info_all.geonameid4.num    = geoip2_db_geonameid_v4_best[GeoIP2_LITE].num;
+			db_info_all.geonameid4.dbtype = geoip2_db_geonameid_v4_best[GeoIP2_LITE].dbtype;
+			db_info_all.geonameid4.dbym   = geoip2_db_geonameid_v4_best[GeoIP2_LITE].dbym;
+			db_info_all.geonameid6.num    = geoip2_db_geonameid_v6_best[GeoIP2_LITE].num;
+			db_info_all.geonameid6.dbtype = geoip2_db_geonameid_v6_best[GeoIP2_LITE].dbtype;
+			db_info_all.geonameid6.dbym   = geoip2_db_geonameid_v6_best[GeoIP2_LITE].dbym;
+			libipv6calc_db_wrapper_print_db_info_line(level_verbose, prefix_string, "GeoIP(MMDB)", "detected best databases LITE", 1, db_info_all, 0);
+
+			db_info_all.country4.num    = geoip2_db_country_v4_best[GeoIP2_COMM].num;
+			db_info_all.country4.dbtype = geoip2_db_country_v4_best[GeoIP2_COMM].dbtype;
+			db_info_all.country4.dbym   = geoip2_db_country_v4_best[GeoIP2_COMM].dbym;
+			db_info_all.country6.num    = geoip2_db_country_v6_best[GeoIP2_COMM].num;
+			db_info_all.country6.dbtype = geoip2_db_country_v6_best[GeoIP2_COMM].dbtype;
+			db_info_all.country6.dbym   = geoip2_db_country_v6_best[GeoIP2_COMM].dbym;
+			db_info_all.city4.num    = geoip2_db_region_city_v4_best[GeoIP2_COMM].num;
+			db_info_all.city4.dbtype = geoip2_db_region_city_v4_best[GeoIP2_COMM].dbtype;
+			db_info_all.city4.dbym   = geoip2_db_region_city_v4_best[GeoIP2_COMM].dbym;
+			db_info_all.city6.num    = geoip2_db_region_city_v6_best[GeoIP2_COMM].num;
+			db_info_all.city6.dbtype = geoip2_db_region_city_v6_best[GeoIP2_COMM].dbtype;
+			db_info_all.city6.dbym   = geoip2_db_region_city_v6_best[GeoIP2_COMM].dbym;
+			db_info_all.asn4.num    = geoip2_db_asn_v4_best[GeoIP2_COMM].num;
+			db_info_all.asn4.dbtype = geoip2_db_asn_v4_best[GeoIP2_COMM].dbtype;
+			db_info_all.asn4.dbym   = geoip2_db_asn_v4_best[GeoIP2_COMM].dbym;
+			db_info_all.asn6.num    = geoip2_db_asn_v6_best[GeoIP2_COMM].num;
+			db_info_all.asn6.dbtype = geoip2_db_asn_v6_best[GeoIP2_COMM].dbtype;
+			db_info_all.asn6.dbym   = geoip2_db_asn_v6_best[GeoIP2_COMM].dbym;
+			db_info_all.geonameid4.num    = geoip2_db_geonameid_v4_best[GeoIP2_COMM].num;
+			db_info_all.geonameid4.dbtype = geoip2_db_geonameid_v4_best[GeoIP2_COMM].dbtype;
+			db_info_all.geonameid4.dbym   = geoip2_db_geonameid_v4_best[GeoIP2_COMM].dbym;
+			db_info_all.geonameid6.num    = geoip2_db_geonameid_v6_best[GeoIP2_COMM].num;
+			db_info_all.geonameid6.dbtype = geoip2_db_geonameid_v6_best[GeoIP2_COMM].dbtype;
+			db_info_all.geonameid6.dbym   = geoip2_db_geonameid_v6_best[GeoIP2_COMM].dbym;
+			libipv6calc_db_wrapper_print_db_info_line(level_verbose, prefix_string, "GeoIP(MMDB)", "detected best databases COMM", 1, db_info_all, 0);
+
+			db_info_all.country4.num    = geoip2_db_country_v4;
+			db_info_all.country6.num    = geoip2_db_country_v6;
+			db_info_all.city4.num    = geoip2_db_region_city_v4;
+			db_info_all.city6.num    = geoip2_db_region_city_v6;
+			db_info_all.asn4.num    = geoip2_db_asn_v4;
+			db_info_all.asn6.num    = geoip2_db_asn_v6;
+			db_info_all.geonameid4.num    = geoip2_db_geonameid_v4;
+			db_info_all.geonameid6.num    = geoip2_db_geonameid_v6;
+			libipv6calc_db_wrapper_print_db_info_line(level_verbose, prefix_string, "GeoIP(MMDB)", "selected best databases normal", 1, db_info_all, 1);
 
 			if (geoip2_db_comm_to_free_switch_min_delta_months > 0) {
-				fprintf(stderr, "%sGeoIP2: selected best databases method: COMM older than %d months are deselected in case of FREE is available\n"
+				fprintf(stderr, "%sGeoIP(MMDB): selected best databases method : COMM older than %d months are deselected in case of LITE is available\n"
 					, prefix
 					, geoip2_db_comm_to_free_switch_min_delta_months
 				);
 			};
 
 			if (geoip2_db_better_max_delta_months > 0) {
-				fprintf(stderr, "%sGeoIP2: selected best databases method: COMM/FREE with more features are only selected in case not older than %d months of already found COMM/FREE\n"
+				fprintf(stderr, "%sGeoIP(MMDB): selected best databases method : COMM/LITE with more features are only selected in case not older than %d months of already found COMM/LITE\n"
 					, prefix
 					, geoip2_db_better_max_delta_months
 				);
 			};
 
 			if (geoip2_db_only_type > 0) {
-				fprintf(stderr, "%sGeoIP2: selected best databases method: by applying given DB type filter: %d\n"
+				fprintf(stderr, "%sGeoIP2(MMDB): selected best databases method : by applying given DB type filter: %d\n"
 					, prefix
 					, geoip2_db_only_type
 				);
@@ -533,16 +555,17 @@ char *libipv6calc_db_wrapper_GeoIP2_wrapper_db_info_used(void) {
 
 			DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP2, "type=%d info=%s", type, info);
 
+			STRCLR(tempstring);
 			if (strlen(geoip2_db_usage_string) > 0) {
 				if (strstr(geoip2_db_usage_string, info) != NULL) {
 					DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP2, "type=%d info=%s (skip, already displayed)", type, info);
 					continue;
 				}; // string already included
 
-				snprintf(tempstring, sizeof(tempstring), "%s / %s", geoip2_db_usage_string, info);
-			} else {
-				snprintf(tempstring, sizeof(tempstring), "%s", info);
+				STRCAT(tempstring, geoip2_db_usage_string);
+				STRCAT(tempstring, " / ");
 			};
+			STRCAT(tempstring, info);
 
 			snprintf(geoip2_db_usage_string, sizeof(geoip2_db_usage_string), "%s", tempstring);
 			DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP2, "type=%d geoip2_db_usage_string=%s", type, geoip2_db_usage_string);
@@ -577,7 +600,10 @@ static char *libipv6calc_db_wrapper_GeoIP2_dbfilename(const unsigned int type) {
 		return(NULL);
 	};
 
-	snprintf(tempstring, sizeof(tempstring), "%s/%s", geoip2_db_dir, libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].filename);
+	STRCLR(tempstring);
+	STRCAT(tempstring, geoip2_db_dir);
+	STRCAT(tempstring, "/");
+	STRCAT(tempstring, libipv6calc_db_wrapper_GeoIP2_db_file_desc[i].filename);
 
 	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP2, "Finished: %s type=%d has filename=%s", wrapper_geoip2_info, type, tempstring);
 
@@ -720,7 +746,6 @@ END_libipv6calc_db_wrapper:
 char *libipv6calc_db_wrapper_GeoIP2_database_info(const unsigned int type) {
 	static char resultstring[IPV6CALC_STRING_MAX];
 	char datastring[IPV6CALC_STRING_MAX];
-	char tempstring[IPV6CALC_STRING_MAX];
 
 	MMDB_s mmdb;
 	int ret, i, entry = -1;
@@ -786,8 +811,8 @@ char *libipv6calc_db_wrapper_GeoIP2_database_info(const unsigned int type) {
 	);
 
 	strftime(datastring, sizeof(datastring), "%Y%m%d-%H%M%S UTC", gmtime(&epoch));
-	snprintf(tempstring, sizeof(tempstring), "%s, created: %s", resultstring, datastring);
-	snprintf(resultstring, sizeof(resultstring), "%s", tempstring);
+	STRCAT(resultstring, ", created: ");
+	STRCAT(resultstring, datastring);
 
 END_libipv6calc_db_wrapper:
 	return(resultstring);
@@ -862,28 +887,35 @@ int libipv6calc_db_wrapper_GeoIP2_wrapper_country_code_by_addr(const ipv6calc_ip
 
 	GeoIP2_DB_USAGE_MAP_TAG(GeoIP2_type);
 
-	goto END_libipv6calc_db_wrapper; // keep db open
-
 END_libipv6calc_db_wrapper:
 	return(result);
 };
 
 
-/* ASN */
-uint32_t libipv6calc_db_wrapper_GeoIP2_wrapper_asn_by_addr(const ipv6calc_ipaddr *ipaddrp) {
-	uint32_t result = ASNUM_AS_UNKNOWN;
+/*
+ * get AS 32-bit number and orgname (optional)
+ * in : ipaddrp (mandatory)
+ * in : data_source_ptr (optional, can be NULL)
+ * out: as_orgname (optional if not NULL and as_orgname_length != 0)
+ * in : as_orgname_length (optional required != 0)
+ * out: AS 32-bit number
+ */
+uint32_t libipv6calc_db_wrapper_GeoIP2_wrapper_asn_by_addr(const ipv6calc_ipaddr *ipaddrp, char *as_orgname, const size_t as_orgname_length) {
+	uint32_t as_num = ASNUM_AS_UNKNOWN;
+	int result;
 
-	int GEOIP2_type = 0;
+	int GeoIP2_type = 0;
+	libipv6calc_db_wrapper_geolocation_record record_asn;
 
 	if (ipaddrp->proto == IPV6CALC_PROTO_IPV4) {
-		GEOIP2_type = geoip2_db_asn_v4;
+		GeoIP2_type = geoip2_db_asn_v4;
 
 		if ((wrapper_features_by_source[IPV6CALC_DB_SOURCE_GEOIP2] & IPV6CALC_DB_IPV4_TO_AS) == 0) {
 			DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP2, "No GeoIP2 database supporting IPv4 ASN");
 			goto END_libipv6calc_db_wrapper;
 		};
 	} else if (ipaddrp->proto == IPV6CALC_PROTO_IPV6) {
-		GEOIP2_type = geoip2_db_asn_v6;
+		GeoIP2_type = geoip2_db_asn_v6;
 
 		if ((wrapper_features_by_source[IPV6CALC_DB_SOURCE_GEOIP2] & IPV6CALC_DB_IPV6_TO_AS) == 0) {
 			DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP2, "No GeoIP2 database supporting IPv6 ASN");
@@ -894,28 +926,45 @@ uint32_t libipv6calc_db_wrapper_GeoIP2_wrapper_asn_by_addr(const ipv6calc_ipaddr
 		goto END_libipv6calc_db_wrapper;
 	};
 
-	result = libipv6calc_db_wrapper_GeoIP2_open_type(GEOIP2_type);
+	result = libipv6calc_db_wrapper_GeoIP2_open_type(GeoIP2_type);
 
 	if (result != MMDB_SUCCESS) {
 		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP2, "Error opening GeoIP2 by type");
 		goto END_libipv6calc_db_wrapper;
 	};
 
-	result = libipv6calc_db_wrapper_MMDB_asn_by_addr(ipaddrp, &mmdb_cache[GEOIP2_type]);
+	// AS Number only
+	as_num = libipv6calc_db_wrapper_MMDB_asn_by_addr(ipaddrp, &mmdb_cache[GeoIP2_type]);
  
-	if (result == ASNUM_AS_UNKNOWN) {
+	if (as_num == ASNUM_AS_UNKNOWN) {
 		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP2, "no match found");
 		goto END_libipv6calc_db_wrapper;
 	};
 
-	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP2, "result ASN=%u", result);
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP2, "result AS_NUM=%u", as_num);
 
-	GeoIP2_DB_USAGE_MAP_TAG(GEOIP2_type);
+	// AS Text (optional)
+	if ((as_orgname != NULL) && (as_orgname_length > 0)) {
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP2, "lookup AS_ORGNAME as_orgname=%p as_orgname_length=%lu", as_orgname, (long unsigned int) as_orgname_length);
+		result = libipv6calc_db_wrapper_MMDB_all_by_addr(ipaddrp, &record_asn, &mmdb_cache[GeoIP2_type]);
 
-	goto END_libipv6calc_db_wrapper;
+		if (result != MMDB_SUCCESS) {
+			DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP2, "no match found");
+			goto END_libipv6calc_db_wrapper;
+		};
+
+		// copy information
+		snprintf(as_orgname, as_orgname_length, "%s", record_asn.organization_name);
+
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP2, "result AS_ORGNAME=%s", as_orgname);
+	} else {
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP2, "lookup AS_ORGNAME skipped as_orgname=%p as_orgname_length=%lu", as_orgname, (long unsigned int) as_orgname_length);
+	};
+
+	GeoIP2_DB_USAGE_MAP_TAG(GeoIP2_type);
 
 END_libipv6calc_db_wrapper:
-	return(result);
+	return(as_num);
 };
 
 
@@ -923,17 +972,17 @@ END_libipv6calc_db_wrapper:
 uint32_t libipv6calc_db_wrapper_GeoIP2_wrapper_GeonameID_by_addr(const ipv6calc_ipaddr *ipaddrp, int *source_ptr) {
 	uint32_t result = IPV6CALC_DB_GEO_GEONAMEID_UNKNOWN;
 
-	int GEOIP2_type = 0;
+	int GeoIP2_type = 0;
 
 	if (ipaddrp->proto == IPV6CALC_PROTO_IPV4) {
-		GEOIP2_type = geoip2_db_region_city_v4;
+		GeoIP2_type = geoip2_db_geonameid_v4;
 
 		if ((wrapper_features_by_source[IPV6CALC_DB_SOURCE_GEOIP2] & IPV6CALC_DB_IPV4_TO_GEONAMEID) == 0) {
 			DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP2, "No GeoIP2 database supporting IPv4 GeonameID");
 			goto END_libipv6calc_db_wrapper;
 		};
 	} else if (ipaddrp->proto == IPV6CALC_PROTO_IPV6) {
-		GEOIP2_type = geoip2_db_region_city_v6;
+		GeoIP2_type = geoip2_db_geonameid_v6;
 
 		if ((wrapper_features_by_source[IPV6CALC_DB_SOURCE_GEOIP2] & IPV6CALC_DB_IPV6_TO_GEONAMEID) == 0) {
 			DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP2, "No GeoIP2 database supporting IPv6 GeonameID");
@@ -944,14 +993,14 @@ uint32_t libipv6calc_db_wrapper_GeoIP2_wrapper_GeonameID_by_addr(const ipv6calc_
 		goto END_libipv6calc_db_wrapper;
 	};
 
-	result = libipv6calc_db_wrapper_GeoIP2_open_type(GEOIP2_type);
+	result = libipv6calc_db_wrapper_GeoIP2_open_type(GeoIP2_type);
 
 	if (result != MMDB_SUCCESS) {
 		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP2, "Error opening GeoIP2 by type");
 		goto END_libipv6calc_db_wrapper;
 	};
 
-	result = libipv6calc_db_wrapper_MMDB_GeonameID_by_addr(ipaddrp, &mmdb_cache[GEOIP2_type], source_ptr);
+	result = libipv6calc_db_wrapper_MMDB_GeonameID_by_addr(ipaddrp, &mmdb_cache[GeoIP2_type], source_ptr);
 
 	if (result == IPV6CALC_DB_GEO_GEONAMEID_UNKNOWN) {
 		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP2, "no match found");
@@ -960,9 +1009,7 @@ uint32_t libipv6calc_db_wrapper_GeoIP2_wrapper_GeonameID_by_addr(const ipv6calc_
 
 	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP2, "result GeonameID=%u", result);
 
-	GeoIP2_DB_USAGE_MAP_TAG(GEOIP2_type);
-
-	goto END_libipv6calc_db_wrapper;
+	GeoIP2_DB_USAGE_MAP_TAG(GeoIP2_type);
 
 END_libipv6calc_db_wrapper:
 	return(result);
@@ -978,6 +1025,8 @@ int libipv6calc_db_wrapper_GeoIP2_all_by_addr(const ipv6calc_ipaddr *ipaddrp, li
 
 	libipv6calc_db_wrapper_geolocation_record record_asn;
 
+	libipv6calc_db_wrapper_geolocation_record_clear(recordp);
+
 	if (ipaddrp->proto == IPV6CALC_PROTO_IPV4) {
 		GeoIP2_type = geoip2_db_region_city_v4;
 		GeoIP2_type_asn = geoip2_db_asn_v4;
@@ -1033,8 +1082,12 @@ int libipv6calc_db_wrapper_GeoIP2_all_by_addr(const ipv6calc_ipaddr *ipaddrp, li
 		// copy information
 		recordp->asn = record_asn.asn;
                 snprintf(recordp->organization_name, IPV6CALC_DB_SIZE_ORG_NAME, "%s", record_asn.organization_name);
+
+		GeoIP2_DB_USAGE_MAP_TAG(GeoIP2_type_asn);
 	};
 
+	GeoIP2_DB_USAGE_MAP_TAG(GeoIP2_type);
+
 END_libipv6calc_db_wrapper:
 	return(result);
 };
