@@ -1,8 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : databases/lib/libipv6calc_db_wrapper_GeoIP2.h
- * Version    : $Id: 690f127e48eaf4d4aa7c1d5072a62bcde913cd63 $
- * Copyright  : 2019-2021 by Peter Bieringer <pb (at) bieringer.de>
+ * Copyright  : 2019-2025 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Header file for libipv6calc_db_wrapper_GeoIP2.c
@@ -24,13 +23,9 @@
 #define GeoIP2_DB_ISP					6	// commercial
 #define GeoIP2_DB_MAX					GeoIP2_DB_ISP
 
-#define IPV6CALC_DB_GEOIP2_INTERNAL_FREE		0x00000001
+#define IPV6CALC_DB_GEOIP2_INTERNAL_LITE		0x00000001
 #define IPV6CALC_DB_GEOIP2_INTERNAL_COMM		0x00000002
 
-
-// features
-extern uint32_t wrapper_features_GeoIP2;
-
 #endif
 
 
@@ -47,7 +42,7 @@ extern int         libipv6calc_db_wrapper_GeoIP2_has_features(const uint32_t fea
 #include "libipv6calc_db_wrapper_MMDB.h"
 
 extern int         libipv6calc_db_wrapper_GeoIP2_wrapper_country_code_by_addr(const ipv6calc_ipaddr *ipaddrp, char *country, const size_t country_len);
-extern uint32_t    libipv6calc_db_wrapper_GeoIP2_wrapper_asn_by_addr(const ipv6calc_ipaddr *ipaddrp);
+extern uint32_t    libipv6calc_db_wrapper_GeoIP2_wrapper_asn_by_addr(const ipv6calc_ipaddr *ipaddrp, char *as_orgname, const size_t as_orgname_length);
 extern uint32_t    libipv6calc_db_wrapper_GeoIP2_wrapper_GeonameID_by_addr(const ipv6calc_ipaddr *ipaddrp, int *source_ptr);
 extern int         libipv6calc_db_wrapper_GeoIP2_all_by_addr(const ipv6calc_ipaddr *ipaddrp, libipv6calc_db_wrapper_geolocation_record *recordp);
 
