@@ -100,7 +100,7 @@ testscenarios_ipv4_reserved() {
 192.167.255.255		noRFC
 192.168.0.0		RFC1918#3
 192.168.255.255		RFC1918#3
-192.169.0.0		noRFC
+192.169.0.0		noRFC		skip-anon-test
 198.17.255.255		noRFC
 198.18.0.0		RFC2544#C.2.2
 198.19.255.255		RFC2544#C.2.2
