@@ -1,8 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6loganonhelp.c
- * Version    : $Id: 3c2d4bae6d300cedf1aa801ef2eeb3571261b37a $
- * Copyright  : 2007-2013 by Peter Bieringer <pb (at) bieringer.de>
+ * Copyright  : 2007-2025 by Peter Bieringer <pb (at) bieringer.de>
  * License    : GNU GPL v2
  *
  * Information:
@@ -34,6 +33,10 @@ void printversion(void) {
 		fprintf(stderr, " ANON_KEEP-TYPE-ASN-CC");
 	};
 
+	if (feature_kg == 1) {
+		fprintf(stderr, " ANON_KEEP-TYPE-GEONAMEID");
+	};
+
 	fprintf(stderr, "\n");
 };
 
@@ -42,9 +45,10 @@ void printversion_help(void) {
 
 	fprintf(stderr, "Explanation of available(x)/possible(o) feature tokens\n");
 
-	fprintf(stderr, "%-22s%c %s\n", "ANON_ZEROISE", (feature_zeroize == 1)? 'x' : 'o', "Anonymization method 'zeroize'");
-	fprintf(stderr, "%-22s%c %s\n", "ANON_ANONYMIZE", (feature_anon == 1) ? 'x' : 'o', "Anonymization method 'anonymize'");
-	fprintf(stderr, "%-22s%c %s\n", "ANON_KEEP-TYPE-ASN-CC", (feature_kp == 1) ? 'x' : 'o', "Anonymization method 'keep-type-asn-cc'");
+	fprintf(stderr, "%-25s%c %s\n", "ANON_ZEROISE", (feature_zeroize == 1)? 'x' : 'o', "Anonymization method 'zeroize'");
+	fprintf(stderr, "%-25s%c %s\n", "ANON_ANONYMIZE", (feature_anon == 1) ? 'x' : 'o', "Anonymization method 'anonymize'");
+	fprintf(stderr, "%-25s%c %s\n", "ANON_KEEP-TYPE-ASN-CC", (feature_kp == 1) ? 'x' : 'o', "Anonymization method 'keep-type-asn-cc'");
+	fprintf(stderr, "%-25s%c %s\n", "ANON_KEEP-TYPE-GEONAMEID", (feature_kg == 1) ? 'x' : 'o', "Anonymization method 'keep-type-geonameid'");
 
 	fprintf(stderr, "\n");
 };
@@ -87,3 +91,35 @@ void ipv6loganon_printhelp(void) {
 
 	return;
 };
+
+
+// check for feature
+int ipv6loganon_has_feature(void) {
+	if (strcmp(ipv6calcoptions_has_feature_name, "ANON_ZEROISE") == 0) {
+		if (feature_zeroize == 1) {
+			return 0;
+		} else {
+			return 1;
+		};
+	} else if (strcmp(ipv6calcoptions_has_feature_name, "ANON_ANONYMIZE") == 0) {
+		if (feature_anon == 1) {
+			return 0;
+		} else {
+			return 1;
+		};
+	} else if (strcmp(ipv6calcoptions_has_feature_name, "ANON_KEEP-TYPE-ASN-CC") == 0) {
+		if (feature_kp == 1) {
+			return 0;
+		} else {
+			return 1;
+		};
+	} else if (strcmp(ipv6calcoptions_has_feature_name, "ANON_KEEP-TYPE-GEONAMEID") == 0) {
+		if (feature_kg == 1) {
+			return 0;
+		} else {
+			return 1;
+		};
+	};
+
+	return 1;
+};
