@@ -1,8 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6logconv.c
- * Version    : $Id: 1c0dd0452e5812570f95fb49f39af9ff056fda20 $
- * Copyright  : 2002-2021 by Peter Bieringer <pb (at) bieringer.de>
+ * Copyright  : 2002-2025 by Peter Bieringer <pb (at) bieringer.de>
  * 
  * Information:
  *  Dedicated program for logfile conversions
@@ -216,6 +215,11 @@ int main(int argc,char *argv[]) {
 		exit(EXIT_SUCCESS);
 	};
 
+	if (ipv6calcoptions_has_feature_query != 0) {
+		result = ipv6logconv_has_feature();
+		exit(result);
+	};
+
 	/* print help handling */
 	if (command & CMD_printhelp) {
 		ipv6logconv_printhelp();
