@@ -1,8 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6logconvhelp.c
- * Version    : $Id: 19ece2b813c395919e5d0e540532f739a921c7cc $
- * Copyright  : 2002-2014 by Peter Bieringer <pb (at) bieringer.de>
+ * Copyright  : 2002-2025 by Peter Bieringer <pb (at) bieringer.de>
  * License    : GNU GPL v2
  *
  * Information:
@@ -87,3 +86,22 @@ void ipv6logconv_printhelp(void) {
 	return;
 };
 
+
+// check for feature
+int ipv6logconv_has_feature(void) {
+	if (strcmp(ipv6calcoptions_has_feature_name, "CONV_REG") == 0) {
+		if (feature_reg == 1) {
+			return 0;
+		} else {
+			return 1;
+		};
+	} else if (strcmp(ipv6calcoptions_has_feature_name, "CONV_IEEE") == 0) {
+		if (feature_ieee == 1) {
+			return 0;
+		} else {
+			return 1;
+		};
+	};
+
+	return 1;
+};
