@@ -2,8 +2,7 @@
 #
 # Project    : ipv6calc
 # File       : test_ipv6logconv.sh
-# Version    : $Id: 714a225a3a138ff655b772d43861e58dcedb64fa $
-# Copyright  : 2002-2021 by Peter Bieringer <pb (at) bieringer.de>
+# Copyright  : 2002-2025 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Test program for "ipv6logconv"
 
@@ -96,9 +95,16 @@ END_CACHE
 ## main ##
 echo "Run 'ipv6logconv' function tests..." >&2
 
-if ./ipv6logconv -v | grep -w "CONV_REG" | grep -w "CONV_IEEE"; then
-	true
-else
+c=0
+if ./ipv6logconv --has-feature "CONV_REG"; then
+       c=$[ $c + 1 ]
+fi
+
+if ./ipv6logconv --has-feature "CONV_IEEE"; then
+       c=$[ $c + 1 ]
+fi
+
+if [  $c -ne 2 ]; then
 	echo "NOTICE : ipv6logconv tests skipped, at least one required database feature is missing"
 	exit 0
 fi
