@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc/ipv6logstats
  * File       : ipv6logstats.c
- * Copyright  : 2003-2024 by Peter Bieringer <pb (at) bieringer.de>
+ * Copyright  : 2003-2025 by Peter Bieringer <pb (at) bieringer.de>
  * 
  * Information:
  *  Dedicated program for logfile statistics
@@ -291,6 +291,11 @@ int main(int argc,char *argv[]) {
 		exit(EXIT_SUCCESS);
 	};
 
+	if (ipv6calcoptions_has_feature_query != 0) {
+		result = ipv6logstats_has_feature();
+		exit(result);
+	};
+
 	if (command & CMD_printhelp) {
 		ipv6logstats_printhelp();
 		exit(EXIT_FAILURE);
