@@ -1,8 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calcoptions.h
- * Version    : $Id: e7ebcee1bbc43b1111157ec4b3c84162faacf7dc $
- * Copyright  : 2002-2015 by Peter Bieringer <pb (at) bieringer.de>
+ * Copyright  : 2002-2025 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Header file containing options
@@ -33,6 +32,9 @@ typedef struct {
 
 extern int ipv6calc_quiet;
 
+extern int ipv6calcoptions_has_feature_query;
+extern char ipv6calcoptions_has_feature_name[];
+
 extern void ipv6calc_debug_from_env(void);
 extern void ipv6calc_common_options_from_env(const struct option longopts[], s_ipv6calc_anon_set *ipv6calc_anon_set_p);
 extern int ipv6calc_set_option(const struct option longopts[], const char *name, const char *value, s_ipv6calc_anon_set *ipv6calc_anon_set_p);
