@@ -1,22 +1,25 @@
 /*
  * Project    : ipv6calc/lib
  * File       : libipv4addr.h
- * Version    : $Id: 203780546647b9d9155ad672fc324ac9190ede6e $
- * Copyright  : 2002-2019 by Peter Bieringer <pb (at) bieringer.de> except the parts taken from kernel source
+ * Version    : $Id: d3f1fd65720c93d0b06468cc44256bacc21fc4b8 $
+ * Copyright  : 2002-2021 by Peter Bieringer <pb (at) bieringer.de> except the parts taken from kernel source
  * License    : GNU GPL v2
  *
  * Information:
  *  Header file for libipv4addr.c
  */ 
 
-#include "ipv6calctypes.h"
-#include <netinet/in.h>
-
-/* typedefs */
 #ifndef _libipv4addr_h
 
 #define _libipv4addr_h 1
 
+
+#include <netinet/in.h>
+#include "ipv6calctypes.h"
+
+
+/* typedefs */
+
 /* IPv4 address structure */
 typedef struct {
 	struct   in_addr in_addr;	/* in_addr structure */
@@ -29,15 +32,17 @@ typedef struct {
 	uint8_t  test_mode;		/* test mode */
 } ipv6calc_ipv4addr;
 
+
 /* IPv4 Address filter structure */
 typedef struct {
         int active;
         int addr_must_have_max;
         int addr_may_not_have_max;
         ipv6calc_ipv4addr ipv4addr_must_have[IPV6CALC_FILTER_IPV4ADDR];
-        ipv6calc_ipv4addr ipv4addr_may_not_have[IPV6CALC_FILTER_IPV6ADDR];
+        ipv6calc_ipv4addr ipv4addr_may_not_have[IPV6CALC_FILTER_IPV4ADDR];
 } s_ipv6calc_filter_addr_ipv4;
 
+
 /* IPv4 filter structure */
 typedef struct {
 	int active;
@@ -77,39 +82,8 @@ typedef struct {
 #define IPV4_ADDR_LISP_PETR			(uint32_t) 0x00020000U	/* IPv6 LISP Proxy Egress Tunnel Routers (PETRY) Anycast */
 #define IPV4_ADDR_LISP_MAP_RESOLVER		(uint32_t) 0x00040000U	/* IPv6 LISP Map Resolver Anycast */
 
+/* text representations -> libipv4addr.c */
 
-/* text representation */
-/*@unused@*/ static const s_type ipv6calc_ipv4addrtypestrings[] = {
-	{ IPV4_ADDR_ANY			, "any" },
-	{ IPV4_ADDR_UNICAST		, "unicast" },
-	{ IPV4_ADDR_MULTICAST		, "multicast" },
-	{ IPV4_ADDR_ANYCAST		, "anycast" },
-	{ IPV4_ADDR_BROADCAST		, "broadcast" },
-	{ IPV4_ADDR_LOOPBACK		, "loopback" },
-	{ IPV4_ADDR_UNSPECIFIED		, "unspecified" },
-	{ IPV4_ADDR_UNKNOWN		, "unknown" },
-	{ IPV4_ADDR_RESERVED		, "reserved" },
-	{ IPV4_ADDR_ZEROCONF		, "zeroconf" },
-	{ IPV4_ADDR_SITELOCAL		, "site-local" },
-	{ IPV4_ADDR_ANONYMIZED		, "anonymized" },
-	{ IPV4_ADDR_ANONYMIZED_GEONAMEID, "anonymized-geonameid" },
-	{ IPV4_ADDR_GLOBAL		, "global" },
-	{ IPV4_ADDR_6TO4RELAY		, "6to4relay" },
-	{ IPV4_ADDR_LISP	 	, "lisp" },
-	{ IPV4_ADDR_LISP_PETR		, "lisp-proxyegresstunnelrouter-anycast" },
-	{ IPV4_ADDR_LISP_MAP_RESOLVER	, "lisp-mapresolver-anycast" },
-};
-
-
-/* Registries */
-#define IPV4_ADDR_REGISTRY_IANA		REGISTRY_IANA
-#define IPV4_ADDR_REGISTRY_APNIC	REGISTRY_APNIC
-#define IPV4_ADDR_REGISTRY_ARIN		REGISTRY_ARIN
-#define IPV4_ADDR_REGISTRY_RIPENCC	REGISTRY_RIPENCC
-#define IPV4_ADDR_REGISTRY_LACNIC	REGISTRY_LACNIC
-#define IPV4_ADDR_REGISTRY_AFRINIC	REGISTRY_AFRINIC
-#define IPV4_ADDR_REGISTRY_RESERVED	REGISTRY_RESERVED
-#define IPV4_ADDR_REGISTRY_UNKNOWN	REGISTRY_UNKNOWN
 
 /* IPv4 address anonymization type "keep-type-asn-cc"
  *  Global IPv4 addresses are anonymized by storing country code and AS number
@@ -201,6 +175,11 @@ typedef struct {
 #endif
 
 
+/* references */
+extern const s_type ipv6calc_ipv4addrtypestrings[];
+extern const int    ipv6calc_ipv4addrtypestrings_entries;
+
+
 /* prototypes */
 extern uint8_t  ipv4addr_getoctet(const ipv6calc_ipv4addr *ipv4addrp, const unsigned int numoctet);
 extern uint16_t ipv4addr_getword(const ipv6calc_ipv4addr *ipv4addrp, const unsigned int numword);
@@ -229,6 +208,9 @@ extern int libipv4addr_to_reversestring(const ipv6calc_ipv4addr *ipv4addrp, char
 extern int libipv4addr_to_octal(const ipv6calc_ipv4addr *ipv4addrp, char *resultstring, const size_t resultstring_length, const uint32_t formatoptions);
 extern int libipv4addr_to_hex(const ipv6calc_ipv4addr *ipv4addrp, char *resultstring, const size_t resultstring_length, const uint32_t formatoptions);
 
+void ipv4addrstruct_maskprefix(ipv6calc_ipv4addr *ipv4addrp);
+void ipv4addrstruct_masksuffix(ipv6calc_ipv4addr *ipv4addrp);
+
 extern int libipv4addr_anonymize(ipv6calc_ipv4addr *ipv4addrp, const unsigned int mask, const int method);
 extern uint32_t ipv4addr_anonymized_get_as_num32(const ipv6calc_ipv4addr *ipv4addrp);
 extern uint16_t ipv4addr_anonymized_get_cc_index(const ipv6calc_ipv4addr *ipv4addrp);
@@ -242,3 +224,5 @@ extern uint16_t libipv4addr_cc_index_by_addr(const ipv6calc_ipv4addr *ipv4addrp,
 extern uint32_t libipv4addr_as_num32_by_addr(const ipv6calc_ipv4addr *ipv4addrp, unsigned int *data_source_ptr);
 extern uint32_t libipv4addr_GeonameID_by_addr(const ipv6calc_ipv4addr *ipv4addrp, unsigned int *data_source_ptr, unsigned int *GeonameID_type_ptr);
 extern int libipv4addr_registry_num_by_addr(const ipv6calc_ipv4addr *ipv4addrp);
+
+extern void libipv4addr_cleanup();
