@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : librfc2874.c
- * Version    : $Id: 2d9d8ae1457e4be115ebfbc87cc1d6ca79f2abf5 $
+ * Version    : $Id: 74d119dd98f9cd9df1cf7993edafa0c8fb106238 $
  * Copyright  : 2002-2014 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
@@ -31,7 +31,7 @@ int librfc2874_addr_to_bitstring(const ipv6calc_ipv6addr *ipv6addrp, char *resul
 	int retval = 1;
 	unsigned int nibble;
 	unsigned int noctet, nbit, nnibble, prefixlength, bit_start, bit_end;
-	char tempstring[NI_MAXHOST];
+	char tempstring[IPV6CALC_STRING_MAX];
 
 	if ( (*ipv6addrp).flag_startend_use != 0 ) {
 		/* check start and end */
@@ -115,7 +115,7 @@ int librfc2874_addr_to_bitstring(const ipv6calc_ipv6addr *ipv6addrp, char *resul
  */
 int librfc2874_bitstring_to_ipv6addrstruct(const char *inputstring, ipv6calc_ipv6addr *ipv6addrp, char *resultstring, const size_t resultstring_length) {
 	int retval = 1;
-	char tempstring[NI_MAXHOST], tempstring2[NI_MAXHOST];
+	char tempstring[IPV6CALC_STRING_MAX], tempstring2[IPV6CALC_STRING_MAX];
 	unsigned int nibblecounter = 0;
 	unsigned int noctet, startprefixlength, endprefixlength, index = 0, length, prefixlength;
 	int xdigit;
